use isahc::{ReadResponseExt, RequestExt};
use serde::Deserialize;

use crate::{BASE_URL, BunqClient};

pub(super) fn get(client: &BunqClient) -> anyhow::Result<Vec<MonetaryAccount>> {
    let response = isahc::http::Request::get(format!(
        "{}/v1/user/{}/monetary-account",
        BASE_URL, client.user_id
    ))
        .header("X-Bunq-Client-Authentication", &client.token)
        .body(())?
        .send()?
        .text()?;

    let accounts = crate::deserialize_normal_response::<Vec<MonetaryAccount>>(&response)?;

    Ok(accounts.response)
}

#[derive(Deserialize, Debug)]
#[serde(rename_all = "PascalCase")]
pub enum MonetaryAccount {
    MonetaryAccountBank(MonetaryAccountBank),
    MonetaryAccountSavings(MonetaryAccountSavings),
}

#[derive(Deserialize, Debug)]
pub struct MonetaryAccountBank {
    pub id: i64,
    pub description: String,
}

#[derive(Deserialize, Debug)]
pub struct MonetaryAccountSavings {
    pub id: i64,
    pub description: String,
}
